/* mdump

   Interleave and Merge two binary files, and dump them to the screen

   Copyright 2002  Jed Margolin 

   Permission is given to individuals to make copies for their own use.

   All commercial use requires permission of the author. 
   
   Send comments to:  comments@jmargolin.com

   This program was compiled with Microsoft Visual C++ 6.0 
   to run under Console mode.

   It can also be compiled under Borland Turbo C if you 
   comment out  '#include "stdafx.h' .

*/

#include "stdafx.h"  // comment this out if compiling with Borland Turbo C
#include <stdio.h>
#include <string.h>
#include <ctype.h>

#define   FF	12;		
#define   LF	10;

FILE *fopen();
FILE *ifp1;
FILE *ifp2;

unsigned char inbuffer1[4096];
unsigned char inbuffer2[4096];
unsigned char outbuffer[8192];

int conv_hex(char);
int dump(unsigned char *,int);

main(int argc,char **argv)
{
   long n,ptr;
   int nBytes1, nBytes2, done = 0;


   printf("\n");
   printf("mdump    Copyright 2002  Jed Margolin\n\n"); 
   printf("Interleave and Merge two binary files, and Dump them to the screen.\n\n");
 
// Do we have the correct number of arguments?
   if(argc < 3)
   {
       printf("Usage: mdump <infile1.ext> <infile2.bin>\n");
       return(1);
   }

// Open the files
   if((ifp1= fopen(argv[1],"rb")) == NULL)
   {
	  perror(argv[1]);
	  return(1);
   }

   if((ifp2= fopen(argv[2],"rb")) == NULL)
   {
	  perror(argv[2]);
	  fclose(ifp1);
	  return(1);
   }

   printf("Input Files to Merge and Interleave:   %s   %s\n",argv[1],argv[2]);

   while(!done)
   {
      nBytes1=fread(inbuffer1,1,4096,ifp1);	// read a block from input file 1
      nBytes2=fread(inbuffer2,1,4096,ifp2);	// read a block from input file 2

      if(feof(ifp1))	   { break;}		// end of file 1
      if(feof(ifp2))	   { break;}        // end of file 2

      if(nBytes1 != nBytes2)
      {
	     printf("\nThe file sizes do not match");
	     printf("\nFile merge terminated");
	     printf("\nThe output dump might not be valid");
	     done = 1;
      }

      ptr = 0;
      for(n=0;n<nBytes1;n++)  		// interleave them
      {
	     outbuffer[ptr++] = inbuffer1[n];
	     outbuffer[ptr++] = inbuffer2[n];
      }

      dump(outbuffer,nBytes1+nBytes2);               // write to output file
   }

   fclose(ifp1);
   fclose(ifp2);

   printf("\n\nDone\n\n");

   return(0);   // return successfully
}

//===============================================
int conv_hex(char val)
{
   if(val>47 && val<58)   return(val-48);	/* digit */
   if(val>64 && val<71)   return(val-55);	/* upper case alpha */
   if(val>96 && val<103)  return(val-87);	/* lower case alpha */
   return(0);
}
//================================================
// Dump a buffer to the screen
dump(unsigned char *buffer,int nBytes)
{
   int ptr,done;
   long m,n;
   static long address = 0;
 

// do one line of 16 values
   done = 0;
   ptr = 0;
   while(!done)
   {
	  for(n=0;n<16;n++)
	  {
	
         // print address 
         printf(" \n%06lX  ",address);

         // print data in hex
         for(m=0;m<16;m++)
		 {
	       printf("%02X ",buffer[ptr++]);
		 }

		 // print data in ascii
         ptr = ptr-16;		// restore ptr to start of line data
         printf("   ");
 
		 for(m=0;m<16;m++)
		 {
	        if(isprint(buffer[ptr]&0xFF) == 0)   
			{ 
			   printf("."); 
			}
	        else 
			{
			   printf("%c",(buffer[ptr]&0xFF)); 
			}

		    ptr++;
		 }

		 address = address + 16;

	  } // end of line


	  // more data?
	  if(nBytes<=ptr)  { done = 1; }
	  
   } // end while  
   return(0);
}

//================================================


